##############################################################################
# drifter.world plots part of the world that all the drifters travel,
# which includes the South Atlantic and Indian Oceans.
##############################################################################

drifter.world <- function()
{
	rmp<-as.vector(scan("rmp"))
	gwm <-matrix(scan("gwm_2.fmt"),ncol=2,byrow=T)
	lon<-gwm[,1]
	lat<-gwm[,2]

	plot(lon, lat, type = "n", xlab = "Longitude", ylab ="Latitude"
	   ,ylim=c(-45, -15),xlim=c(-75, 98))
#	   ,ylim=c(-90, 90), xlim=c(-180, 180))  
	rmp1 <- cumsum(rmp)
	rmp1 <- append(rmp1, 0, 0)
	for(j in 1:(length(rmp1) - 1)) {
            i1 <<- rmp1[j] + 1
	    i2 <<- rmp1[j + 1]

	    if (j == 2)	# plotting Africa
	    {
		lines(lon[(i1+210):(i1+272)],lat[(i1+210):(i1+272)],lwd=3)
		lines(lon[(i1+337):(i1+411)],lat[(i1+337):(i1+411)],lwd=3)
	    }

	    else if (j == 3) # plotting South America
		lines(lon[(i1+1270):(i1+1422)],lat[(i1+1270):(i1+1422)], lwd=3)

	    else if (j == 36) # plotting Madagascar
	    {
		lines(lon[i1:(i1+36)], lat[i1:(i1+36)], lwd=3)
		lines(lon[(i1+50):i2], lat[(i1+50):i2], lwd=3)
	    }
		
	}
	text(-55, -18, "South\nAmerica", cex=1.2)
	text(25, -18, "Africa", cex=1.2)
	text(63, -18, "Madagascar", cex=1.2)
}

##############################################################################
# plot.drifter plots a list of drifters, which is the output from
# read.vel() or scan.drifter().  If the option "scale" is TRUE, all
# the drifters are plotted with the same scale.  
##############################################################################

plot.drifter <- function( drifter.list, scale=F )
{	
	if (scale)
	{
		x <- numeric(0)
		y <- numeric(0)
		for (i in 1:length(drifter.list))
		{
		  x <- c(x, drifter.list[[i]]$long)
		  y <- c(y, drifter.list[[i]]$lat)
		}
		for (i in 1:length(drifter.list))
	  	  plot(drifter.list[[i]]$longitude, 
			drifter.list[[i]]$latitude,
 			xlab="Longitude", ylab="Latitude", type='l',
			ylim=range(y), xlim=range(x))	
	}
	else
	  for (i in 1:length(drifter.list))
		 plot(drifter.list[[i]]$longitude, 
			drifter.list[[i]]$latitude, 
			xlab="Longitude", ylab="Latitude", type='l')
}

##############################################################################
# plot.traj plots the trajectories of a list of drifters and
# superimposes the parts that intersect in time if the option "inter" is
# TRUE.  
##############################################################################

plot.traj <- function( ..., inter=F )
{
	all.drifter <- list(...)

	drifter.world()
	for (i in 1:length(all.drifter))
	  lines(all.drifter[[i]]$long, all.drifter[[i]]$lat, 
		col=(i %% 5) + 2)	

	if (inter)
	{
	  a <- max(sapply(all.drifter, function(x) min(x$days)))
	  b <- min(sapply(all.drifter, function(x) max(x$days)))
	
	  ind <- sapply(all.drifter, 
			function(x, a, b) x$days >= a & x$days <= b, a, b)
	  num.inter <- sum(ind[[1]]) # number of days intersect

	  for (i in 1:num.inter)
	    for (j in 1:length(all.drifter))
		points( all.drifter[[j]]$long[ind[[j]]][i],
			all.drifter[[j]]$lat[ind[[j]]][i], 
			col=(j %% 5) + 2 )
	}
	
	invisible()
}

##############################################################################
# motion plots all the existing drifters between the time frame starting
# from "starting" for "n" days.  If the option plot.all is TRUE, all the
# drifters will be plotted.
##############################################################################

motion <- function( drifter=d, starting=2446200, n=100, plot.all=F )
{
	drifter.world()

	if ( plot.all ) # plot all the drifters 
  	  for (i in 1:length(drifter))
	    lines(drifter[[i]]$long, drifter[[i]]$lat, col=2+(i %% 5))

	else
	{
	  to <- starting + n

	  # find the drifters that exist in the range
	  count <- 0
	  index <- numeric(length(drifter))
	  for (i in 1:length(drifter))
	    if ((min(drifter[[i]]$days) <= to) & 
		 max(drifter[[i]]$days <= starting))
	    {
		count <- count + 1
		index[count] <- i
	    }
	  index <- index[1:count]
	  color <- (1:count %% 5) + 2

	  for (i in starting:to)
	  {
		for (j in 1:length(index))
		  if (sum(drifter[[index[j]]]$days == i))
		  {
		    m <- i - min(drifter[[index[j]]]$days) + 1
		    points(drifter[[index[j]]]$long[m],
			   drifter[[index[j]]]$lat[m], col=color[j])
		  }
	  }
	}
}


